/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "../lib/mesh.h"

int main(int argc, char *argv[])
{
	gctl::regular_grid rgd;
	rgd.init("grid-1", "null", 4, 4, 0.0, 0.0, 1.0, 1.0);

	gctl::meshdata *data = rgd.add_data("data-1", gctl::NodeData, true, 2.5);
	gctl::meshdata *data2= rgd.add_data("data-2", gctl::ElemData, false, 1.2);
	gctl::meshdata *data3= rgd.add_data("data-3", gctl::NodeData, true, gctl::Scalar);

	std::cout << "data name: " << data2->get_datname() << std::endl;
	//gctl::array<double> *data_ptr = (gctl::array<double>*) rgd.get_datval(data2->get_name());
	gctl::array<double> *data_ptr = (gctl::array<double>*) data2->get_datval_ptr();
	for (int i = 0; i < data_ptr->size(); i++)
	{
		std::cout << data_ptr->at(i) << std::endl;
	}

	std::cout << "data name: " << data3->get_datname() << std::endl;
	gctl::array<int> *data_ptr2 = (gctl::array<int>*) rgd.get_datval(data3->get_datname());
	for (int i = 0; i < data_ptr2->size(); i++)
	{
		std::cout << data_ptr2->at(i) << std::endl;
	}

	rgd.remove_data("data-1");

	return 0;
}