/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "../lib/mesh.h"

int main(int argc, char *argv[])
{
	try
	{
		std::string dname = "example";
		std::string dname2= "another-example";

		gctl::regular_grid rgd;
		rgd.init("grid-1", "this is a test message.", 15, 10, 0.0, 0.0, 1.0, 1.0);
		rgd.add_data(dname, gctl::NodeData, true, gctl::Scalar);

		gctl::array<double> *data_ptr = (gctl::array<double>*) rgd.get_datval(dname);
		for (int j = 0; j < rgd.get_ydim(); j++)
		{
			for (int i = 0; i < rgd.get_xdim(); i++)
			{
				data_ptr->at(i + j*rgd.get_xdim()) = i;
			}
		}

		rgd.add_data(dname2, gctl::ElemData, true, gctl::Scalar);
		data_ptr = (gctl::array<double>*) rgd.get_datval(dname2);
		for (int j = 0; j < rgd.get_ydim()-1; j++)
		{
			for (int i = 0; i < rgd.get_xdim()-1; i++)
			{
				data_ptr->at(i + j*(rgd.get_xdim()-1)) = j;
			}
		}

		rgd.save_binary("data/out/sample3-out");
		rgd.save_netcdf_grid("data/out/sample3-out1", dname);
		rgd.save_netcdf_grid("data/out/sample3-out2", dname2);

		gctl::regular_grid rgd2;
		rgd2.load_binary("data/out/sample3-out");

		rgd2.show_info();

		data_ptr = (gctl::array<double>*) rgd2.get_datval(dname);
		for (int i = 0; i < data_ptr->size(); i++)
		{
			std::cout << data_ptr->at(i) << " ";
		}
		std::cout << std::endl;

		data_ptr = (gctl::array<double>*) rgd2.get_datval(dname2);
		for (int i = 0; i < data_ptr->size(); i++)
		{
			std::cout << data_ptr->at(i) << " ";
		}
		std::cout << std::endl;
	}
	catch(std::exception &e)
	{
		GCTL_ShowWhatError(e.what(), GCTL_ERROR_ERROR, 0, 0, 0);
	}
	return 0;
}