/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2022  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "../lib/mesh.h"

int main(int argc, char *argv[])
{
	try
	{
		gctl::regular_mesh_2d rg_mesh;
		rg_mesh.init("mesh-example", "this mesh can store vectors. Yeah!", 15, 10, 0.5, 0.5, 1.0, 1.0);

		int ybnum = rg_mesh.get_ybnum();
		int xbnum = rg_mesh.get_xbnum();

		rg_mesh.add_data("vector-data", gctl::ElemData, true, gctl::Vector);
		gctl::array<gctl::point3dc> *data_ptr = (gctl::array<gctl::point3dc>*) rg_mesh.get_datval("vector-data");
		for (int j = 0; j < ybnum; j++)
		{
			for (int i = 0; i < xbnum; i++)
			{
				data_ptr->at(i + j*xbnum).x = i;
				data_ptr->at(i + j*xbnum).y = j;
				data_ptr->at(i + j*xbnum).z = i+j;
			}
		}

		rg_mesh.add_data("double-data", gctl::NodeData, true, gctl::Scalar);
		gctl::array<double> *data_ptr2 = (gctl::array<double>*) rg_mesh.get_datval("double-data");
		for (int j = 0; j < ybnum+1; j++)
		{
			for (int i = 0; i < xbnum+1; i++)
			{
				data_ptr2->at(i + j*(xbnum+1)) = i+j;
			}
		}

		//rg_mesh.save_gmsh("data/sample6-out", "vector-data");
		//rg_mesh.save_gmsh("data/sample6-out", "double-data", Append);

		rg_mesh.save_gmsh("data/out/sample6-out", gctl::ElemData, gctl::OverWrite);
	}
	catch(std::exception &e)
	{
		GCTL_ShowWhatError(e.what(), GCTL_ERROR_ERROR, 0, 0, 0);
	}
	return 0;
}