﻿/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2023  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#include "meshdata.h"

gctl::meshdata::meshdata(std::string in_name, mesh_data_type_e in_type, bool if_output)
{
	if (in_name == "")
	{
		throw std::runtime_error("[gctl::meshdata] The input name is empty.");
	}

	datname = in_name;
	dattype = in_type;
	output_ok = if_output;
}

gctl::meshdata::~meshdata(){}

void gctl::meshdata::set_datname(std::string in_name)
{
	if (in_name == "")
	{
		throw std::runtime_error("[gctl::meshdata] The input name is empty.");
	}

	datname = in_name;
	return;
}

std::string gctl::meshdata::get_datname()
{
	return datname;
}

gctl::mesh_data_type_e gctl::meshdata::get_dattype()
{
	return dattype;
}

gctl::mesh_data_value_e gctl::meshdata::get_valtype()
{
	return valtype;
}

void gctl::meshdata::set_output(bool if_output)
{
	output_ok = if_output;
	return;
}

bool gctl::meshdata::get_output()
{
	return output_ok;
}

void gctl::meshdata::show_info(std::ostream &os)
{
	os << "Data: " << datname << " | ";
	if (dattype == NodeData) os << "Type: Node data | ";
	if (dattype == ElemData) os << "Type: Element data | ";
	if (dattype == ElemData2D) os << "Type: 2D element data | ";
	if (dattype == ElemData3D) os << "Type: 3D element data | ";
	if (valtype == Scalar) os << "Value: Scalar | ";
	if (valtype == Vector) os << "Value: Vector | ";
	if (valtype == Tensor) os << "Value: Tensor | ";
	if (output_ok) os << "Output: Yes" << std::endl;
	else os<< "Output: No" << std::endl;
	return;
}