﻿/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2023  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#ifndef _GCTL_REGULAR_MESH_2D_H
#define _GCTL_REGULAR_MESH_2D_H

#include "mesh.h"

namespace gctl
{
	class regular_mesh_2d : public base_mesh
	{
	public:

		/**
		 * 以下为mesh类型的虚函数实现
		 */

		void init(std::string in_name, std::string in_info, int xbnum, int ybnum, 
			double xmin, double ymin, double xsize, double ysize);

		void load_binary(std::string filename);
		void save_binary(std::string filename);

		/**
		 * 以下为regular_mesh_2d的专有函数
		 */

		regular_mesh_2d();
		regular_mesh_2d(std::string in_name, std::string in_info, int xbnum, int ybnum, 
			double xmin, double ymin, double xsize, double ysize);
		virtual ~regular_mesh_2d();

		int get_xbnum() const;
		int get_ybnum() const;
		double get_xmin() const;
		double get_ymin() const;
		double get_xsize() const;
		double get_ysize() const;

		void save_gmsh(std::string filename, index_packed_e packed = Packed);
		void save_gmsh(std::string filename, mesh_data_type_e d_type, output_type_e out_mode, index_packed_e packed = Packed);
		void save_gmsh(std::string filename, std::string datname, output_type_e out_mode, index_packed_e packed = Packed);

	protected:
		int rm_xbnum, rm_ybnum;
		double rm_xmin, rm_ymin;
		double rm_xsize, rm_ysize;
		array<vertex2dc> nodes;
		array<rectangle2d> elements;
	};
}

#endif //_GCTL_REGULAR_MESH_2D_H