﻿/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2023  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#ifndef _GCTL_TRI_MESH_H
#define _GCTL_TRI_MESH_H

#include "mesh.h"

namespace gctl
{
	class triangle_mesh : public base_mesh
	{
	public:

		/**
		 * 以下为mesh类型的虚函数实现
		 */

		void init(std::string in_name, std::string in_info, const array<vertex2dc> &in_nodes, 
			const array<triangle2d> &in_triangles);

		void load_binary(std::string filename);
		void save_binary(std::string filename);

		/**
		 * 以下为triangle_mesh的专有函数
		 */

		triangle_mesh();
		triangle_mesh(std::string in_name, std::string in_info, const array<vertex2dc> &in_nodes, 
			const array<triangle2d> &in_triangles);
		virtual ~triangle_mesh();

		const array<vertex2dc> &get_nodes() const;
		const array<triangle2d> &get_elements() const;

		void load_triangle(std::string filename, index_packed_e packed = Packed);
		void load_gmsh(std::string filename, index_packed_e packed = Packed);
		void save_gmsh(std::string filename, index_packed_e packed = Packed);
		void save_gmsh(std::string filename, mesh_data_type_e d_type, output_type_e out_mode, index_packed_e packed = Packed);
		void save_gmsh(std::string filename, std::string datname, output_type_e out_mode, index_packed_e packed = Packed);

	protected:
		array<vertex2dc> nodes;
		array<triangle2d> elements;
	};
}

#endif //_GCTL_TRI_MESH_H